# peblarpy
Python Client to Peblar EVCC REST-API

# Disclaimer

This repository is not in any sense related or supported by Peblar or Prodrive Technologies. This is just a personal project from a Peblar user who wants to automate EV Charging using a Pebler EVCC.